@@ -4,5 +4,5 @@ mod run;
 mod types;
 
 pub use dir_diff::{DirDiff, DirDiffError};
-pub use run::{main, test_all};
+pub use run::{main, main_with_filters, test_all};
 pub use types::*;
